The PyDy source code is actually spread across both the SymPy and PyDy
repositories. The two projects are very intimately tied together in terms of
development. Much of our development practices come from SymPy's methods so
reading their documentation for contributing is the best place to start:

https://github.com/sympy/sympy/wiki/introduction-to-contributing

Style
=====

Code written in python should roughly adhere to PEP8:

http://www.python.org/dev/peps/pep-0008/.

There are some exceptions, such as naming of variables. Use your best judgment.

Commit Guidelines
=================

When submitting, please follow the commit guidelines used for Git:

http://git-scm.com/book/ch5-2.html#Commit-Guidelines

The first line should have a soft limit of 50 characters, and subsequent lines
limitted to 72 characters. The commit messages should be written in the
imperative present tense.
